/**
 * Copyright (c) 2000-2011 Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.marketplace.hook.events;

import com.liferay.marketplace.util.MarketplaceConstants;
import com.liferay.marketplace.util.MarketplaceUtil;
import com.liferay.portal.kernel.events.Action;
import com.liferay.portal.kernel.events.ActionException;
import com.liferay.portal.kernel.util.HttpUtil;
import com.liferay.portal.model.User;
import com.liferay.portal.util.PortalUtil;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

/**
 * @author Peter Shin
 */
public class LogoutPostAction extends Action {

	@Override
	public void run(HttpServletRequest request, HttpServletResponse response)
		throws ActionException {

		try {
			doRun(request, response);
		}
		catch (Exception e) {
			throw new ActionException(e);
		}
	}

	protected void doRun(
			HttpServletRequest request, HttpServletResponse response)
		throws Exception {

		User user = PortalUtil.getUser(request);

		if (user == null) {
			return;
		}

		if (user.isDefaultUser()) {
			return;
		}

		if (!MarketplaceUtil.isMarketplaceAdmin(user)) {
			return;
		}

		String redirect = MarketplaceConstants.MARKETPLACE_URL_LOGOUT;

		redirect = HttpUtil.setParameter(
			redirect, "referer", PortalUtil.getCurrentCompleteURL(request));

		response.sendRedirect(redirect);
	}

}